==> u-boot-2011.12.tar.bz2: u-boot-2011.12/inc/common_inc/x_desc.h <==
/* SPDX-License-Identifier: LGPL-2.1-only OR BSD-3-Clause */
/******************************************************************************
 *
 * This file is provided under a dual license.  When you use or
 * distribute this software, you may choose to be licensed under
 * version 2.1 of the GNU Lesser General Public License
 * ("LGPLv2.1 License") or BSD License.
 *
 * LGPLv2.1 License
 *
 * Copyright(C) 2019 MediaTek Inc.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of version 2.1 of the GNU Lesser General Public
 * License as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See https://www.gnu.org/licenses/old-licenses/lgpl-2.1.html for more
 * details.
 *
 * BSD LICENSE
 *
 * Copyright(C) 2019 MediaTek Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 *  * Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *  * Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *  * Neither the name of the copyright holder nor the names of its
 *    contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 *****************************************************************************/

/*-----------------------------------------------------------------------------
 * $RCSfile: x_desc.h,v $
 * $Revision: #1 $
 * $Date: 2015/11/10 $
 * $Author: dtvbm11 $
 *
 * Description:
 *         This header file contains descrambler driver specific definitions,
 *         which are exported.
 *----------------------------------------------------------------------------*/

#ifndef _X_DESC_H_
#define _X_DESC_H_

/*-----------------------------------------------------------------------------
                    include files
 -----------------------------------------------------------------------------*/

#include "x_common.h"
#include "x_rm.h"

/*-----------------------------------------------------------------------------
                    macros, defines, typedefs, enums
 ----------------------------------------------------------------------------*/
/* Get operations */
#define DESC_GET_TYPE_CTRL          (RM_GET_TYPE_LAST_ENTRY + ((DRV_GET_TYPE_T) 0))
#define DESC_GET_TYPE_ALGORITHM	    (RM_GET_TYPE_LAST_ENTRY + ((DRV_GET_TYPE_T) 1))
#define DESC_GET_TYPE_PID           (RM_GET_TYPE_LAST_ENTRY + ((DRV_GET_TYPE_T) 2))

/* Set operations */
#define DESC_SET_TYPE_CTRL          ((RM_SET_TYPE_LAST_ENTRY + ((DRV_SET_TYPE_T) 0)) | RM_SET_TYPE_ARG_NO_REF)
#define DESC_SET_TYPE_ALGORITHM     (RM_SET_TYPE_LAST_ENTRY + ((DRV_SET_TYPE_T) 1))
#define DESC_SET_TYPE_PID           ((RM_SET_TYPE_LAST_ENTRY + ((DRV_SET_TYPE_T) 2)) | RM_SET_TYPE_ARG_NO_REF)
#define DESC_SET_TYPE_ODD_KEY       (RM_SET_TYPE_LAST_ENTRY + ((DRV_SET_TYPE_T) 3))
#define DESC_SET_TYPE_EVEN_KEY      (RM_SET_TYPE_LAST_ENTRY + ((DRV_SET_TYPE_T) 4))
#define DESC_SET_TYPE_SOURCE        (RM_SET_TYPE_LAST_ENTRY + ((DRV_SET_TYPE_T) 5))
#define DESC_SET_TYPE_KEY_INDEX     ((RM_SET_TYPE_LAST_ENTRY + ((DRV_SET_TYPE_T)6)) | RM_SET_TYPE_ARG_NO_REF)

typedef enum
{
    DESC_SOURCE_NONE = 0,          /* None scramble */
    DESC_SOURCE_DTV,           /* DESC_SOURCE_DTV*/
    DESC_SOURCE_FVR           /* DESC_SOURCE_FVR*/
}   DESC_SOURCE_T;

/* Descrambler algorithms */
typedef enum
{
    DESC_ALG_NONE = 0,          /* None scramble */
    DESC_ALG_DES_ECB,           /* DES-56-ECB*/
    DESC_ALG_DES_CBC,           /* DES-56-CCB*/
    DESC_ALG_3DES_ECB,          /* 3DES-ECB*/
    DESC_ALG_3DES_CBC,          /* 3DES-CCB*/
    DESC_ALG_DVB,               /* DVB */
    DESC_ALG_AES_128_ECB,       /* AES-128-ECB*/
    DESC_ALG_AES_128_CBC        /* AES-128-CCB*/
}   DESC_ALG_T;

/*
   Descrambler algorithms in bit-mask manner used in
   the argument ui4_comp_flags of the API x_rm_reg_comp()
*/
#define DESC_DRV_FLAG_CAP_DES_ECB   MAKE_BIT_MASK_32(DESC_ALG_DES_ECB  + ((DESC_ALG_T) 16))
#define DESC_DRV_FLAG_CAP_DES_CBC   MAKE_BIT_MASK_32(DESC_ALG_DES_CBC  + ((DESC_ALG_T) 16))
#define DESC_DRV_FLAG_CAP_3DES_ECB  MAKE_BIT_MASK_32(DESC_ALG_3DES_ECB + ((DESC_ALG_T) 16))
#define DESC_DRV_FLAG_CAP_3DES_CBC  MAKE_BIT_MASK_32(DESC_ALG_3DES_CBC + ((DESC_ALG_T) 16))
#define DESC_DRV_FLAG_CAP_DVB       MAKE_BIT_MASK_32(DESC_ALG_DVB      + ((DESC_ALG_T) 16))

/* DES EBC Key information */
typedef struct _DES_ECB_KEY_INFO_T
{
    SIZE_T          z_key_len;    /* size of key in byte */
    const UINT8*    pui1_key;     /* pointer of key buffer */
} DES_ECB_KEY_INFO_T;

/* AES CBC Key information */
typedef struct _AES_128_CBC_KEY_INFO_T
{
    SIZE_T          z_key_len;    /* size of key in byte */
    const UINT8*    pui1_key;     /* pointer of key buffer */
    SIZE_T          z_iv_len;     /* size of iv in byte */
    const UINT8*    pui1_iv;      /* pointer of iv buffer */
} AES_128_CBC_KEY_INFO_T;

/* Definition of descrambler key information */
typedef struct _DESC_KEY_INFO_T
{
    DESC_ALG_T e_descrambler_alg;                   /* descrambler algorithm */
    union
    {
        DES_ECB_KEY_INFO_T t_des_ecb_key;          /*DES-56-ECB*/
        AES_128_CBC_KEY_INFO_T t_aes_128_cbc_key;  /*AES-128-CBC*/
    }u_key_info;
}   DESC_KEY_INFO_T;

#endif /* _X_DESC_H_ */

==> u-boot-2011.12-2011.12.tar.bz2: u-boot-2011.12-2011.12/inc/common_inc/x_desc.h <==
/* SPDX-License-Identifier: LGPL-2.1-only OR BSD-3-Clause */
/******************************************************************************
 *
 * This file is provided under a dual license.  When you use or
 * distribute this software, you may choose to be licensed under
 * version 2.1 of the GNU Lesser General Public License
 * ("LGPLv2.1 License") or BSD License.
 *
 * LGPLv2.1 License
 *
 * Copyright(C) 2019 MediaTek Inc.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of version 2.1 of the GNU Lesser General Public
 * License as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See https://www.gnu.org/licenses/old-licenses/lgpl-2.1.html for more
 * details.
 *
 * BSD LICENSE
 *
 * Copyright(C) 2019 MediaTek Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 *  * Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *  * Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *  * Neither the name of the copyright holder nor the names of its
 *    contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 *****************************************************************************/

/*-----------------------------------------------------------------------------
 * $RCSfile: x_desc.h,v $
 * $Revision$
 * $Date$
 * $Author$
 *
 * Description:
 *         This header file contains descrambler driver specific definitions,
 *         which are exported.
 *----------------------------------------------------------------------------*/

#ifndef _X_DESC_H_
#define _X_DESC_H_

/*-----------------------------------------------------------------------------
                    include files
 -----------------------------------------------------------------------------*/

#include "x_common.h"
#include "x_rm.h"

/*-----------------------------------------------------------------------------
                    macros, defines, typedefs, enums
 ----------------------------------------------------------------------------*/
/* Get operations */
#define DESC_GET_TYPE_CTRL          (RM_GET_TYPE_LAST_ENTRY + ((DRV_GET_TYPE_T) 0))
#define DESC_GET_TYPE_ALGORITHM	    (RM_GET_TYPE_LAST_ENTRY + ((DRV_GET_TYPE_T) 1))
#define DESC_GET_TYPE_PID           (RM_GET_TYPE_LAST_ENTRY + ((DRV_GET_TYPE_T) 2))

/* Set operations */
#define DESC_SET_TYPE_CTRL         ((RM_SET_TYPE_LAST_ENTRY + ((DRV_SET_TYPE_T) 0)) | RM_SET_TYPE_ARG_NO_REF)
#define DESC_SET_TYPE_ALGORITHM     (RM_SET_TYPE_LAST_ENTRY + ((DRV_SET_TYPE_T) 1))
#define DESC_SET_TYPE_PID          ((RM_SET_TYPE_LAST_ENTRY + ((DRV_SET_TYPE_T) 2)) | RM_SET_TYPE_ARG_NO_REF)
#define DESC_SET_TYPE_ODD_KEY       (RM_SET_TYPE_LAST_ENTRY + ((DRV_SET_TYPE_T) 3))
#define DESC_SET_TYPE_EVEN_KEY      (RM_SET_TYPE_LAST_ENTRY + ((DRV_SET_TYPE_T) 4))
#define DESC_SET_TYPE_SOURCE        (RM_SET_TYPE_LAST_ENTRY + ((DRV_SET_TYPE_T) 5))
#define DESC_SET_TYPE_KEY_INDEX     ((RM_SET_TYPE_LAST_ENTRY + ((DRV_SET_TYPE_T)6)) | RM_SET_TYPE_ARG_NO_REF)

typedef enum
{
    DESC_SOURCE_NONE = 0,          /* None scramble */
    DESC_SOURCE_DTV,           /* DESC_SOURCE_DTV*/
    DESC_SOURCE_FVR           /* DESC_SOURCE_FVR*/
}   DESC_SOURCE_T;

/* Descrambler algorithms */
typedef enum
{
    DESC_ALG_NONE = 0,          /* None scramble */
    DESC_ALG_DES_ECB,           /* DES-56-ECB*/
    DESC_ALG_DES_CBC,           /* DES-56-CCB*/
    DESC_ALG_3DES_ECB,          /* 3DES-ECB*/
    DESC_ALG_3DES_CBC,          /* 3DES-CCB*/
    DESC_ALG_DVB,               /* DVB */
    DESC_ALG_AES_128_ECB,       /* AES-128-ECB*/
    DESC_ALG_AES_128_CBC,        /* AES-128-CCB*/
    DESC_ALG_CA_SECURE          /* SECURE KEY */
}   DESC_ALG_T;

/*
   Descrambler algorithms in bit-mask manner used in
   the argument ui4_comp_flags of the API x_rm_reg_comp()
*/
#define DESC_DRV_FLAG_CAP_DES_ECB   MAKE_BIT_MASK_32(DESC_ALG_DES_ECB  + ((DESC_ALG_T) 16))
#define DESC_DRV_FLAG_CAP_DES_CBC   MAKE_BIT_MASK_32(DESC_ALG_DES_CBC  + ((DESC_ALG_T) 16))
#define DESC_DRV_FLAG_CAP_3DES_ECB  MAKE_BIT_MASK_32(DESC_ALG_3DES_ECB + ((DESC_ALG_T) 16))
#define DESC_DRV_FLAG_CAP_3DES_CBC  MAKE_BIT_MASK_32(DESC_ALG_3DES_CBC + ((DESC_ALG_T) 16))
#define DESC_DRV_FLAG_CAP_DVB       MAKE_BIT_MASK_32(DESC_ALG_DVB      + ((DESC_ALG_T) 16))

/* DES EBC Key information */
typedef struct _DES_ECB_KEY_INFO_T
{
    SIZE_T          z_key_len;    /* size of key in byte */
    const UINT8*    pui1_key;     /* pointer of key buffer */
} DES_ECB_KEY_INFO_T;

/* AES CBC Key information */
typedef struct _AES_128_CBC_KEY_INFO_T
{
    SIZE_T          z_key_len;    /* size of key in byte */
    const UINT8*    pui1_key;     /* pointer of key buffer */
    SIZE_T          z_iv_len;     /* size of iv in byte */
    const UINT8*    pui1_iv;      /* pointer of iv buffer */
} AES_128_CBC_KEY_INFO_T;

/* DVB Key information */
typedef struct _DVB_KEY_INFO_T
{
    SIZE_T          z_key_len;    /* size of key in byte */
    const UINT8*    pui1_key;     /* pointer of key buffer */
    BOOL            b_is_conf_mode; /*flag for conf mode of dvb key*/
} DVB_KEY_INFO_T;

/* Definition of descrambler key information */
typedef struct _DESC_KEY_INFO_T
{
    DESC_ALG_T e_descrambler_alg;                   /* descrambler algorithm */
    union
    {
        DES_ECB_KEY_INFO_T t_des_ecb_key;          /*DES-56-ECB*/
        AES_128_CBC_KEY_INFO_T t_aes_128_cbc_key;  /*AES-128-CBC*/
        DVB_KEY_INFO_T t_dvb_key;                  /*DVB KEY*/
    }u_key_info;
}   DESC_KEY_INFO_T;

#endif /* _X_DESC_H_ */
